@@ -15,7 +15,8 @@ using namespace perspective;
 namespace perspective {
 namespace numpy {
 
-    const std::vector<std::string> NumpyLoader::DATE_UNITS = {"[D]", "[W]", "[M]", "[Y]"};
+    const std::vector<std::string> NumpyLoader::DATE_UNITS
+        = {"[D]", "[W]", "[M]", "[Y]"};
 
     NumpyLoader::NumpyLoader(t_val accessor)
         : m_init(false)
@@ -30,14 +31,17 @@ namespace numpy {
         m_init = true;
     }
 
-    std::vector<t_dtype> 
-    NumpyLoader::reconcile_dtypes(const std::vector<t_dtype>& inferred_types) const {
+    std::vector<t_dtype>
+    NumpyLoader::reconcile_dtypes(
+        const std::vector<t_dtype>& inferred_types) const {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         std::uint32_t num_columns = m_names.size();
         std::vector<t_dtype> reconciled_types(num_columns);
 
-        // Get numpy dtypes as string so we can tell the difference between dates and datetimes
-        std::vector<std::string> str_dtypes = m_accessor.attr("types")().cast<std::vector<std::string>>();
+        // Get numpy dtypes as string so we can tell the difference between
+        // dates and datetimes
+        std::vector<std::string> str_dtypes
+            = m_accessor.attr("types")().cast<std::vector<std::string>>();
 
         for (auto i = 0; i < num_columns; ++i) {
             std::string numpy_type_as_string = str_dtypes[i];
@@ -45,7 +49,7 @@ namespace numpy {
             t_dtype inferred_type = inferred_types[i];
 
             // Check whether column is a date or a datetime
-            if(numpy_type_as_string.find("datetime64") != std::string::npos) {
+            if (numpy_type_as_string.find("datetime64") != std::string::npos) {
                 for (const std::string& unit : DATE_UNITS) {
                     if (numpy_type_as_string.find(unit) != std::string::npos) {
                         inferred_type = DTYPE_DATE;
@@ -53,7 +57,8 @@ namespace numpy {
                 }
             }
 
-            // Otherwise, numpy type takes precedence unless date/object - need specificity of inferred type
+            // Otherwise, numpy type takes precedence unless date/object - need
+            // specificity of inferred type
             if (inferred_type == DTYPE_DATE || numpy_type == DTYPE_OBJECT) {
                 reconciled_types[i] = inferred_type;
             } else {
@@ -84,7 +89,8 @@ namespace numpy {
 
     void
     NumpyLoader::fill_table(t_data_table& tbl, const t_schema& input_schema,
-        const std::string& index, std::uint32_t offset, std::uint32_t limit, bool is_update) {
+        const std::string& index, std::uint32_t offset, std::uint32_t limit,
+        bool is_update) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         bool implicit_index = false;
         std::vector<std::string> col_names(input_schema.columns());
@@ -96,8 +102,10 @@ namespace numpy {
 
             if (name == "__INDEX__") {
                 implicit_index = true;
-                std::shared_ptr<t_column> pkey_col_sptr = tbl.add_column_sptr("psp_pkey", type, true);
-                fill_column(tbl, pkey_col_sptr, "__INDEX__", type, cidx, is_update);
+                std::shared_ptr<t_column> pkey_col_sptr
+                    = tbl.add_column_sptr("psp_pkey", type, true);
+                fill_column(
+                    tbl, pkey_col_sptr, "__INDEX__", type, cidx, is_update);
                 tbl.clone_column("psp_pkey", "psp_okey");
                 continue;
             }
@@ -109,13 +117,16 @@ namespace numpy {
         // Fill index column - recreated every time a `t_data_table` is created.
         if (!implicit_index) {
             if (index == "") {
-                // Use row number as index if not explicitly provided or provided with `__INDEX__`
+                // Use row number as index if not explicitly provided or
+                // provided with `__INDEX__`
                 auto key_col = tbl.add_column("psp_pkey", DTYPE_INT32, true);
                 auto okey_col = tbl.add_column("psp_okey", DTYPE_INT32, true);
 
                 for (std::uint32_t ridx = 0; ridx < tbl.size(); ++ridx) {
-                    key_col->set_nth<std::int32_t>(ridx, (ridx + offset) % limit);
-                    okey_col->set_nth<std::int32_t>(ridx, (ridx + offset) % limit);
+                    key_col->set_nth<std::int32_t>(
+                        ridx, (ridx + offset) % limit);
+                    okey_col->set_nth<std::int32_t>(
+                        ridx, (ridx + offset) % limit);
                 }
             } else {
                 tbl.clone_column(index, "psp_pkey");
@@ -124,14 +135,16 @@ namespace numpy {
         }
     }
 
-    
-    void 
-    NumpyLoader::fill_column(t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype type, std::uint32_t cidx, bool is_update) {
+    void
+    NumpyLoader::fill_column(t_data_table& tbl, std::shared_ptr<t_column> col,
+        const std::string& name, t_dtype type, std::uint32_t cidx,
+        bool is_update) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
 
-        // Use name index instead of column index - prevents off-by-one errors with the "index" column.
-        auto name_it = std::find(m_names.begin(), m_names.end(), name); 
-        
+        // Use name index instead of column index - prevents off-by-one errors
+        // with the "index" column.
+        auto name_it = std::find(m_names.begin(), m_names.end(), name);
+
         // If the column name is not in the dataset, return and move on.
         if (name_it == m_names.end()) {
             return;
@@ -141,44 +154,61 @@ namespace numpy {
 
         // np_dtype is one of the integer/float/bool dtypes, or `DTYPE_OBJECT`.
         t_dtype np_dtype = m_types[nidx];
-       
+
         py::dict source = m_accessor.attr("_get_numpy_column")(name);
         py::array array = source["array"].cast<py::array>();
-        py::array_t<std::uint64_t> mask = source["mask"].cast<py::array_t<std::uint64_t>>();
-        std::uint64_t* mask_ptr = (std::uint64_t*) mask.data();
+        py::array_t<std::uint64_t> mask
+            = source["mask"].cast<py::array_t<std::uint64_t>>();
+        std::uint64_t* mask_ptr = (std::uint64_t*)mask.data();
         std::size_t mask_size = mask.size();
 
-        // Check array dtype to make sure that `deconstruct_numpy` didn't cast it to an object.
+        // Check array dtype to make sure that `deconstruct_numpy` didn't cast
+        // it to an object.
         if (array.dtype().kind() == 'O') {
-            fill_column_iter(array, tbl, col, name, DTYPE_OBJECT, type, cidx, is_update);
+            fill_column_iter(
+                array, tbl, col, name, DTYPE_OBJECT, type, cidx, is_update);
             return;
         }
 
-        // Datetimes are not trivially copyable - they are float64 values that need to be read as int64
+        // Datetimes are not trivially copyable - they are float64 values that
+        // need to be read as int64
         if (type == DTYPE_TIME || type == DTYPE_DATE) {
-            fill_column_iter(array, tbl, col, name, np_dtype, type, cidx, is_update);
+            fill_column_iter(
+                array, tbl, col, name, np_dtype, type, cidx, is_update);
             fill_validity_map(col, mask_ptr, mask_size, is_update);
             return;
         }
-        
-         /**
-         * Catch common type mismatches and fill iteratively when a numpy dtype is of greater bit width than the Perspective t_dtype:
-         * - when `np_dtype` is int64 and `t_dtype` is `DTYPE_INT32` or `DTYPE_FLOAT64`
-         * - when `np_dtype` is int32 and `t_dtype` is `DTYPE_INT64` or `DTYPE_FLOAT64`, which can happen on windows where np::int_ is int32
-         * - when `np_dtype` is float64 and `t_dtype` is `DTYPE_INT32` or `DTYPE_INT64`
-         * - when `type` is float64 and `np_dtype` is `DTYPE_FLOAT32` or `DTYPE_FLOAT64`
-         * 
-         * These errors occur frqeuently when a Table is created from non-numpy data or schema, then updated with a numpy array.
-         * In these cases, the `t_dtype` of the Table supercedes the array dtype.
+
+        /**
+         * Catch common type mismatches and fill iteratively when a numpy dtype
+         * is of greater bit width than the Perspective t_dtype:
+         * - when `np_dtype` is int64 and `t_dtype` is `DTYPE_INT32` or
+         * `DTYPE_FLOAT64`
+         * - when `np_dtype` is int32 and `t_dtype` is `DTYPE_INT64` or
+         * `DTYPE_FLOAT64`, which can happen on windows where np::int_ is int32
+         * - when `np_dtype` is float64 and `t_dtype` is `DTYPE_INT32` or
+         * `DTYPE_INT64`
+         * - when `type` is float64 and `np_dtype` is `DTYPE_FLOAT32` or
+         * `DTYPE_FLOAT64`
+         *
+         * These errors occur frqeuently when a Table is created from non-numpy
+         * data or schema, then updated with a numpy array. In these cases, the
+         * `t_dtype` of the Table supercedes the array dtype.
          */
-        bool should_iter = (np_dtype == DTYPE_INT64 && (type == DTYPE_INT32 || type == DTYPE_FLOAT64)) || \
-            (np_dtype == DTYPE_INT32 && (type == DTYPE_INT64 || type == DTYPE_FLOAT64)) || \
-            (np_dtype == DTYPE_FLOAT64 && (type == DTYPE_INT32 || type == DTYPE_INT64)) || \
-            (type == DTYPE_INT64 && (np_dtype == DTYPE_FLOAT32 || np_dtype == DTYPE_FLOAT64));
+        bool should_iter
+            = (np_dtype == DTYPE_INT64
+                  && (type == DTYPE_INT32 || type == DTYPE_FLOAT64))
+            || (np_dtype == DTYPE_INT32
+                && (type == DTYPE_INT64 || type == DTYPE_FLOAT64))
+            || (np_dtype == DTYPE_FLOAT64
+                && (type == DTYPE_INT32 || type == DTYPE_INT64))
+            || (type == DTYPE_INT64
+                && (np_dtype == DTYPE_FLOAT32 || np_dtype == DTYPE_FLOAT64));
 
         if (should_iter) {
             // Skip straight to numeric fill
-            fill_numeric_iter(array, tbl, col, name, np_dtype, type, cidx, is_update);
+            fill_numeric_iter(
+                array, tbl, col, name, np_dtype, type, cidx, is_update);
             return;
         }
 
@@ -186,16 +216,19 @@ namespace numpy {
 
         // Iterate if copy is not supported for the numpy array
         if (copy_status == t_fill_status::FILL_FAIL) {
-            fill_column_iter(array, tbl, col, name, np_dtype, type, cidx, is_update);
+            fill_column_iter(
+                array, tbl, col, name, np_dtype, type, cidx, is_update);
         }
-        
+
         // Fill validity map using null mask
         fill_validity_map(col, mask_ptr, mask_size, is_update);
     }
 
     template <typename T>
     void
-    NumpyLoader::fill_object_iter(t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter(t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -214,10 +247,13 @@ namespace numpy {
         }
     }
 
-    // Add explicit instantiations for int32, int64, and float64 as they have promotion logic
+    // Add explicit instantiations for int32, int64, and float64 as they have
+    // promotion logic
     template <>
     void
-    NumpyLoader::fill_object_iter<std::int32_t>(t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter<std::int32_t>(t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -234,13 +270,15 @@ namespace numpy {
 
             double fval = item.cast<double>();
             if (!is_update && (fval > 2147483647 || fval < -2147483648)) {
-                binding::WARN("Promoting column `%s` to float from int32", name);
+                binding::WARN(
+                    "Promoting column `%s` to float from int32", name);
                 tbl.promote_column(name, DTYPE_FLOAT64, i, true);
                 col = tbl.get_column(name);
                 type = DTYPE_FLOAT64;
                 col->set_nth(i, fval);
             } else if (!is_update && isnan(fval)) {
-                binding::WARN("Promoting column `%s` to string from int32", name);
+                binding::WARN(
+                    "Promoting column `%s` to string from int32", name);
                 tbl.promote_column(name, DTYPE_STR, i, false);
                 col = tbl.get_column(name);
                 fill_object_iter<std::string>(
@@ -254,7 +292,9 @@ namespace numpy {
 
     template <>
     void
-    NumpyLoader::fill_object_iter<std::int64_t>(t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter<std::int64_t>(t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -271,7 +311,8 @@ namespace numpy {
 
             double fval = item.cast<double>();
             if (isnan(fval)) {
-                binding::WARN("Promoting column `%s` to string from int64", name);
+                binding::WARN(
+                    "Promoting column `%s` to string from int64", name);
                 tbl.promote_column(name, DTYPE_STR, i, false);
                 col = tbl.get_column(name);
                 fill_object_iter<std::string>(
@@ -285,7 +326,9 @@ namespace numpy {
 
     template <>
     void
-    NumpyLoader::fill_object_iter<double>(t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter<double>(t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -303,7 +346,8 @@ namespace numpy {
             bool is_float = py::isinstance<py::float_>(item);
             bool is_numpy_nan = is_float && npy_isnan(item.cast<double>());
             if (!is_float || is_numpy_nan) {
-                binding::WARN("Promoting column `%s` to string from float64", name);
+                binding::WARN(
+                    "Promoting column `%s` to string from float64", name);
                 tbl.promote_column(name, DTYPE_STR, i, false);
                 col = tbl.get_column(name);
                 fill_object_iter<std::string>(
@@ -316,37 +360,49 @@ namespace numpy {
 
     // Must be below `fill_object_iter` explicit instantiations.
     void
-    NumpyLoader::fill_column_iter(const py::array& array, t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_column_iter(const py::array& array, t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
-        // Numpy arrays are guaranteed to be continous and valid by the time they enter this block,
-        // but if they're of dtype object, then we need to pass it through `m_accessor.marshal`.
+        // Numpy arrays are guaranteed to be continous and valid by the time
+        // they enter this block, but if they're of dtype object, then we need
+        // to pass it through `m_accessor.marshal`.
         switch (type) {
             case DTYPE_TIME: {
-                // covers dtype `datetime64[us/ns/ms/s]`, date strings, and integer timestamps in ms or s since epoch
+                // covers dtype `datetime64[us/ns/ms/s]`, date strings, and
+                // integer timestamps in ms or s since epoch
                 if (np_dtype != DTYPE_TIME) {
-                    fill_object_iter<std::int64_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::int64_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                 } else {
-                    fill_datetime_iter(array, tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_datetime_iter(
+                        array, tbl, col, name, np_dtype, type, cidx, is_update);
                 }
             } break;
             case DTYPE_DATE: {
-                // `datetime.date` objects or `datetime64[D/W/M/Y]`, always fill by using `marshal`.
+                // `datetime.date` objects or `datetime64[D/W/M/Y]`, always fill
+                // by using `marshal`.
                 fill_date_iter(col, name, np_dtype, type, cidx, is_update);
             } break;
             case DTYPE_BOOL: {
                 if (np_dtype == DTYPE_OBJECT) {
-                    fill_object_iter<bool>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<bool>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                 } else {
-                    fill_bool_iter(array, tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_bool_iter(
+                        array, tbl, col, name, np_dtype, type, cidx, is_update);
                 }
             } break;
             case DTYPE_STR: {
                 // dtype `U`
-                fill_object_iter<std::string>(tbl, col, name, np_dtype, type, cidx, is_update);
+                fill_object_iter<std::string>(
+                    tbl, col, name, np_dtype, type, cidx, is_update);
             } break;
             default: {
-                // dtype `i/u/f` - fill_numeric_iter checks again for `dtype=object`
-                fill_numeric_iter(array, tbl, col, name, np_dtype, type, cidx, is_update);
+                // dtype `i/u/f` - fill_numeric_iter checks again for
+                // `dtype=object`
+                fill_numeric_iter(
+                    array, tbl, col, name, np_dtype, type, cidx, is_update);
                 break;
             }
         }
@@ -354,22 +410,26 @@ namespace numpy {
 
     // `array.dtype=datetime64[ns/us/ms/s]`
     void
-    NumpyLoader::fill_datetime_iter(const py::array& array, t_data_table& tbl, std::shared_ptr<t_column> col, 
-        const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_datetime_iter(const py::array& array, t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
 
         // read the array as a double array because of `numpy.nat`
-        double* ptr = (double*) array.data();
+        double* ptr = (double*)array.data();
 
         for (auto i = 0; i < nrows; ++i) {
-            std::int64_t item = ptr[i]; // Perspective stores datetimes using int64
+            std::int64_t item
+                = ptr[i]; // Perspective stores datetimes using int64
             col->set_nth(i, item);
         }
     }
 
     void
-    NumpyLoader::fill_date_iter(std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_date_iter(std::shared_ptr<t_column> col,
+        const std::string& name, t_dtype np_dtype, t_dtype type,
+        std::uint32_t cidx, bool is_update) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
 
@@ -385,24 +445,29 @@ namespace numpy {
                 continue;
             }
 
-            auto date_components = item.cast<std::map<std::string, std::int32_t>>();
+            auto date_components
+                = item.cast<std::map<std::string, std::int32_t>>();
             // date_components["month"] should be [0-11]
-            t_date dt = t_date(date_components["year"], date_components["month"], date_components["day"]);
+            t_date dt = t_date(date_components["year"],
+                date_components["month"], date_components["day"]);
             col->set_nth(i, dt);
         }
     }
 
     void
-    NumpyLoader::fill_bool_iter(const py::array& array, t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_bool_iter(const py::array& array, t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
 
         // handle Nan/None in boolean array with dtype=object
         if (np_dtype == DTYPE_OBJECT) {
             // handle object arrays
-            fill_object_iter<bool>(tbl, col, name, np_dtype, type, cidx, is_update); 
+            fill_object_iter<bool>(
+                tbl, col, name, np_dtype, type, cidx, is_update);
         } else {
-            bool* ptr = (bool*) array.data(); 
+            bool* ptr = (bool*)array.data();
 
             for (auto i = 0; i < nrows; ++i) {
                 bool item = ptr[i];
@@ -411,68 +476,88 @@ namespace numpy {
         }
     }
 
-    void 
-    NumpyLoader::fill_numeric_iter(const py::array& array, t_data_table& tbl, std::shared_ptr<t_column> col, const std::string& name, t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    void
+    NumpyLoader::fill_numeric_iter(const py::array& array, t_data_table& tbl,
+        std::shared_ptr<t_column> col, const std::string& name,
+        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
         const void* ptr = array.data();
 
-        // We fill by object when `np_dtype`=object, or if there are type mismatches between `np_dtype` and `type`.
-        bool types_mismatched = (np_dtype == DTYPE_INT64 && (type == DTYPE_INT32 || type == DTYPE_FLOAT64)) || \
-            (np_dtype == DTYPE_INT32 && (type == DTYPE_INT64 || type == DTYPE_FLOAT64)) || \
-            (np_dtype == DTYPE_FLOAT64 && (type == DTYPE_INT32 || type == DTYPE_INT64)) || \
-            (type == DTYPE_INT64 && (np_dtype == DTYPE_FLOAT32 || np_dtype == DTYPE_FLOAT64));
+        // We fill by object when `np_dtype`=object, or if there are type
+        // mismatches between `np_dtype` and `type`.
+        bool types_mismatched
+            = (np_dtype == DTYPE_INT64
+                  && (type == DTYPE_INT32 || type == DTYPE_FLOAT64))
+            || (np_dtype == DTYPE_INT32
+                && (type == DTYPE_INT64 || type == DTYPE_FLOAT64))
+            || (np_dtype == DTYPE_FLOAT64
+                && (type == DTYPE_INT32 || type == DTYPE_INT64))
+            || (type == DTYPE_INT64
+                && (np_dtype == DTYPE_FLOAT32 || np_dtype == DTYPE_FLOAT64));
 
         if (types_mismatched || np_dtype == DTYPE_OBJECT) {
             switch (type) {
                 case DTYPE_UINT8: {
-                    fill_object_iter<std::uint8_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::uint8_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_UINT16: {
-                    fill_object_iter<std::uint16_t> (tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::uint16_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_UINT32: {
-                    fill_object_iter<std::uint32_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::uint32_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_UINT64: {
-                    fill_object_iter<std::uint64_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::uint64_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_INT8: {
-                    fill_object_iter<std::int8_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::int8_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_INT16: {
-                    fill_object_iter<std::int16_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::int16_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_INT32: {
-                    fill_object_iter<std::int32_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::int32_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_INT64: {
-                    fill_object_iter<std::int64_t>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<std::int64_t>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_FLOAT32: {
-                    fill_object_iter<float>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<float>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 case DTYPE_FLOAT64: {
-                    fill_object_iter<double>(tbl, col, name, np_dtype, type, cidx, is_update);
+                    fill_object_iter<double>(
+                        tbl, col, name, np_dtype, type, cidx, is_update);
                     return;
                 } break;
                 default:
-                    PSP_COMPLAIN_AND_ABORT("Unable to fill non-numeric column `"  + name + "` in `fill_numeric_iter`.")
+                    PSP_COMPLAIN_AND_ABORT("Unable to fill non-numeric column `"
+                        + name + "` in `fill_numeric_iter`.")
             }
         }
 
-        // Iterate through the C++ array and try to cast. Array is guaranteed to be of the correct dtype and consistent in its values.
+        // Iterate through the C++ array and try to cast. Array is guaranteed to
+        // be of the correct dtype and consistent in its values.
         for (auto i = 0; i < nrows; ++i) {
-            if (isnan(((double*) ptr)[i]) || npy_isnan(((double*) ptr)[i])) {
+            if (isnan(((double*)ptr)[i]) || npy_isnan(((double*)ptr)[i])) {
                 if (is_update) {
                     col->unset(i);
                 } else {
@@ -502,13 +587,13 @@ namespace numpy {
                 } break;
                 case DTYPE_INT32: {
                     // No need for promotion logic if array is consistent
-                    col->set_nth<std::int32_t>(i, ((std::int32_t*) ptr)[i]);
+                    col->set_nth<std::int32_t>(i, ((std::int32_t*)ptr)[i]);
                 } break;
                 case DTYPE_INT64: {
-                    col->set_nth<std::int64_t>(i, ((std::int64_t*) ptr)[i]);
+                    col->set_nth<std::int64_t>(i, ((std::int64_t*)ptr)[i]);
                 } break;
                 case DTYPE_FLOAT32: {
-                    col->set_nth(i, ((float*) ptr)[i]);
+                    col->set_nth(i, ((float*)ptr)[i]);
                 } break;
                 case DTYPE_FLOAT64: {
                     col->set_nth<double>(i, ((double*)ptr)[i]);
@@ -523,8 +608,10 @@ namespace numpy {
      *
      * Copy numpy arrays into columns
      */
-    t_fill_status 
-    NumpyLoader::try_copy_array(const py::array& src, std::shared_ptr<t_column> dest, t_dtype np_dtype, t_dtype type, const std::uint64_t offset) {
+    t_fill_status
+    NumpyLoader::try_copy_array(const py::array& src,
+        std::shared_ptr<t_column> dest, t_dtype np_dtype, t_dtype type,
+        const std::uint64_t offset) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         std::int64_t length = src.size();
 
@@ -569,9 +656,10 @@ namespace numpy {
     }
 
     void
-    NumpyLoader::fill_validity_map(
-        std::shared_ptr<t_column> col, std::uint64_t* mask_ptr, std::size_t mask_size, bool is_update) {
-        // Validity map needs to be filled each time - None/np.nan/float('nan') might not have been parsed correctly
+    NumpyLoader::fill_validity_map(std::shared_ptr<t_column> col,
+        std::uint64_t* mask_ptr, std::size_t mask_size, bool is_update) {
+        // Validity map needs to be filled each time - None/np.nan/float('nan')
+        // might not have been parsed correctly
         col->valid_raw_fill();
 
         if (mask_size > 0) {
@@ -587,7 +675,9 @@ namespace numpy {
     }
 
     template <typename T>
-    void copy_array_helper(const void* src, std::shared_ptr<t_column> dest, const std::uint64_t offset) {
+    void
+    copy_array_helper(const void* src, std::shared_ptr<t_column> dest,
+        const std::uint64_t offset) {
         std::memcpy(dest->get_nth<T>(offset), src, dest->size() * sizeof(T));
     }
 
@@ -598,7 +688,8 @@ namespace numpy {
     std::vector<std::string>
     NumpyLoader::make_names() {
         auto data = m_accessor.attr("data")();
-        auto py_names = m_accessor.attr("names")().cast<std::vector<std::string>>();
+        auto py_names
+            = m_accessor.attr("names")().cast<std::vector<std::string>>();
 
         // Match names to dataset - only keep names that are present in dataset.
         // The `m_names` variable is used internally to access the numpy arrays
@@ -618,7 +709,7 @@ namespace numpy {
     std::vector<t_dtype>
     NumpyLoader::make_types() {
         std::vector<t_dtype> rval(m_names.size());
-        
+
         auto data = m_accessor.attr("data")();
 
         for (auto i = 0; i < m_names.size(); ++i) {
@@ -628,10 +719,12 @@ namespace numpy {
             py::array array = py::array::ensure(data[py::str(name)]);
 
             if (!array) {
-                PSP_COMPLAIN_AND_ABORT("Perspective does not support the mixing of ndarrays and lists.");
+                PSP_COMPLAIN_AND_ABORT("Perspective does not support the "
+                                       "mixing of ndarrays and lists.");
             }
 
-            // can't use isinstance on datetime/timedelta array, so check the dtype
+            // can't use isinstance on datetime/timedelta array, so check the
+            // dtype
             char dtype_code = array.dtype().kind();
 
             if (dtype_code == 'M') {
@@ -644,7 +737,8 @@ namespace numpy {
                 continue;
             }
 
-            // isinstance checks equality of underlying dtype, not just pointer equality
+            // isinstance checks equality of underlying dtype, not just pointer
+            // equality
             if (py::isinstance<py::array_t<std::uint8_t>>(array)) {
                 rval[i] = DTYPE_UINT8;
             } else if (py::isinstance<py::array_t<std::uint16_t>>(array)) {
@@ -668,14 +762,15 @@ namespace numpy {
             } else if (py::isinstance<py::array_t<bool>>(array)) {
                 rval[i] = DTYPE_BOOL;
             } else {
-                // DTYPE_OBJECT defers to the inferred type: this allows parsing of datetime strings, boolean strings, etc.
+                // DTYPE_OBJECT defers to the inferred type: this allows parsing
+                // of datetime strings, boolean strings, etc.
                 rval[i] = DTYPE_OBJECT;
             }
         }
 
         return rval;
     }
-    
+
 } // namespace numpy
 } // namespace perspective
 #endif
\ No newline at end of file
